unit Clockfrm;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Anaclock, StdCtrls, ExtCtrls,LargeIni,Classes2;

type
  TClockForm = class(TForm)
    Clock: TAnalogClock;
    P: TPanel;
    cbRoman: TCheckBox;
    TZEdit: TEdit;
    Label1: TLabel;
    procedure cbRomanClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure TZEditChange(Sender: TObject);
  private
    { Private declarations }
    procedure SavePosition(const Key:string);
    procedure LoadPosition(const Key:string);
  public
    { Public declarations }
  end;

implementation

{$R *.DFM}

const
     secDefaults = 'DEFAULTS';

var
   LocalInifile : TLargeInifile;
   IniRefCount : integer;
   Inifilename : string[31];

procedure CheckInifileName;
begin
  if Inifilename='' then InifileName := ChangeFileExt(ExtractFilename(ParamStr(0)),'.INI');
end;

procedure OpenLocalIni;
begin
  if LocalInifile = nil then begin
    CheckInifileName;
    LocalIniFile := TLargeIniFile.Create(IniFileName);
    AddGlobalObject(LocalIniFile);
    IniRefCount := 0;
  end;
  Inc(IniRefCount);
end;

procedure DestroyLocalIni;
begin
  Dec(IniRefCount);
  if IniRefCount = 0 then begin
    LocalIniFile.Free;
    LocalIniFile := nil;
  end;
end;


procedure TClockForm.cbRomanClick(Sender: TObject);
begin
  if cbRoman.Checked then
    Clock.NumberStyle := nsRoman
  else
    Clock.NumberStyle := nsArabic;
end;

procedure TClockForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Action := caFree;
end;

procedure TClockForm.FormCreate(Sender: TObject);
begin
  OpenLocalIni;
  LoadPosition(Classname+'Pos');
  TZEdit.Text := LocalIniFile[secDefaults].GetString('TZone','0');
  DestroyLocalIni;
end;

procedure TClockForm.FormDestroy(Sender: TObject);
begin
  OpenLocalIni;
  SavePosition(Classname+'Pos');
  LocalIniFile[secDefaults].SetString('TZone',TZEdit.Text);
  DestroyLocalIni;
end;

procedure TClockForm.SavePosition(const Key:string);
var L : TTextLine;
    WS : TWindowState;
  procedure GetThePos;
  begin
    WS := WindowState;
    if (WS=wsMaximized) then begin
      L.Line := LocalIniFile[secDefaults].Values[Key];
      try
        ShowWindow(Handle,SW_ShowMinNoActive);
      except
        Exit;
      end;
    end;
    L.Reset;
    L.write([Left,Top,Width,Height,ord(WS)]);
  end;

begin
  try
    OpenLocalIni;
    L := TTextLine.Create;
    GetThePos;
    LocalIniFile[secDefaults].Values[Key] := L.Line;
  finally
    L.Free;
    DestroyLocalIni;
  end;
end;

procedure TClockForm.LoadPosition(const Key:string);
var L : TTextLine;
    WS : TWindowState;
    W,H : integer;
begin
  OpenLocalIni;
  L := TTextLine.Create;
  try
    L.Line := LocalIniFile[secDefaults].Values[Key];
    if not L.eol then begin
      Position := poDesigned;
      try
        WS := TWindowState(StrToIntDef(L[4],ord(wsNormal)));
        Left := L.ReadInt;
        Top := L.ReadInt;
        Width := L.ReadInt;
        Height := L.ReadInt;
      except
      end;
      if WS <> wsMinimized then
        WindowState := WS;
      W := Width div 4;
      if W<20 then W := 20;
      H := Height div 4;
      if H<10 then H := 10;
      if Left+Width<W then Left := 0;
      if Left>Screen.Width-W then Left := 0;
      if Top+Height<H then Top := 0;
      if Top>Screen.Height-H then Top := 0;
    end;
  finally
    L.Free;
    DestroyLocalIni;
  end;
end;

procedure TClockForm.TZEditChange(Sender: TObject);
begin
  Clock.TZone := StrToIntDef(TZEdit.Text,0);
end;

end.
